@@ -3,10 +3,15 @@ var classQore_1_1Json_1_1JsonRpcClient =
     [ "call", "classQore_1_1Json_1_1JsonRpcClient.html#abf29e157d5f15f7f5042b2cba4017d9d", null ],
     [ "callArgs", "classQore_1_1Json_1_1JsonRpcClient.html#a5976d73accc347e8cb4cc931e5859e2d", null ],
     [ "callArgsWithInfo", "classQore_1_1Json_1_1JsonRpcClient.html#a909f1ad09933b222efea80b6c73fb081", null ],
+    [ "callId", "classQore_1_1Json_1_1JsonRpcClient.html#a4a5462bf371ee3c7a07e8eacf49a416a", null ],
+    [ "callIdArgsWithInfo", "classQore_1_1Json_1_1JsonRpcClient.html#ab15386bbe9cb3d07474ad94ab56c10e0", null ],
+    [ "callIdWithInfo", "classQore_1_1Json_1_1JsonRpcClient.html#ae07bcb3c9f1ba2bb16492615362496ea", null ],
     [ "callWithInfo", "classQore_1_1Json_1_1JsonRpcClient.html#a40c1db316998babb9e88a9ee9e1f6080", null ],
     [ "constructor", "classQore_1_1Json_1_1JsonRpcClient.html#ab0db6d61695d4ecb24afed2f1d539686", null ],
     [ "constructor", "classQore_1_1Json_1_1JsonRpcClient.html#a2d54db8a30fd7628361595c619c63034", null ],
     [ "copy", "classQore_1_1Json_1_1JsonRpcClient.html#a8740a9c43fe647afa460313888f1ecde", null ],
+    [ "getVersion", "classQore_1_1Json_1_1JsonRpcClient.html#a9c89f9b1aaae736c2bc1767a32f55311", null ],
     [ "setEventQueue", "classQore_1_1Json_1_1JsonRpcClient.html#a7bd8f0bd545fd22b90765f90d5f8693c", null ],
-    [ "setEventQueue", "classQore_1_1Json_1_1JsonRpcClient.html#a3a39bc987aef19c68d8a0d0a91335384", null ]
+    [ "setEventQueue", "classQore_1_1Json_1_1JsonRpcClient.html#a3a39bc987aef19c68d8a0d0a91335384", null ],
+    [ "setVersion", "classQore_1_1Json_1_1JsonRpcClient.html#aac2a9ebe78c3a5263e7430e21fcb08e6", null ]
 ];
\ No newline at end of file
