@@ -1,5 +1,9 @@
 var group__json__rpc__functions =
 [
+    [ "make_jsonrpc11_error", "group__json__rpc__functions.html#gaff946b396fe84749f8fd8b5b075a8325", null ],
+    [ "make_jsonrpc_error", "group__json__rpc__functions.html#gada7b6d28f535c01b9964e52de2b60a5f", null ],
+    [ "make_jsonrpc_request", "group__json__rpc__functions.html#gada1d72606f131258dae9bd730e8151ae", null ],
+    [ "make_jsonrpc_response", "group__json__rpc__functions.html#ga2d6cde21e126f7f0a39477dd98a68d63", null ],
     [ "makeFormattedJSONRPC11ErrorString", "group__json__rpc__functions.html#gabad2bee01d220c1e7dde784d931fe040", null ],
     [ "makeFormattedJSONRPCErrorString", "group__json__rpc__functions.html#ga424f181b1a0f70fbe3de863a76e1665d", null ],
     [ "makeFormattedJSONRPCRequestString", "group__json__rpc__functions.html#gab5cbe83b37c851dae72bca13901f6a59", null ],
